@@ -24,39 +24,42 @@ import sys
 class Box(object):
     def __init__(self,aff,uid):
         """ You should suply your affiliate and your user id"""
+        self.limit = 6
         self.aff = aff
         self.uid = uid
 
-    def _do_get(self,tags):
+    def _do_get(self,tags,limit):
         import sys
         caller = sys._getframe(1).f_code.co_name
         method = caller.split('_')[-1]
         tags = urllib.quote(tags)
-        add = 'http://boo-box.com/api/format:' + method +'/aff:' + self.aff +'/uid:' + self.uid + '/tags:' + tags
-        content = urllib.urlopen(add).read()
+        url = 'http://boo-box.com/api/format:' + method +'/aff:' + self.aff +'/uid:' + self.uid + '/tags:' + tags
+        if limit and limit != 6:
+            url += '/limit:' + str(limit)
+        content = urllib.urlopen(url).read()
+        return content.strip()
+
+    def _do_get_xml(self,tags,limit):
+        content = self._do_get(tags,limit)
         return content
 
-    def _do_get_xml(self,tags):
-        content = self._do_get(tags)
+    def _do_get_json(self,tags,limit):
+        content = self._do_get(tags,limit)
         return content
 
-    def _do_get_json(self,tags):
-        content = self._do_get(tags)
-        return content
-
-    def _do_get_object(self,tags):
-        content = self._do_get_json(tags)
+    def _do_get_object(self,tags,limit):
+        content = self._do_get_json(tags,limit)
         content = content.replace('jsonBooboxApi(','')
         import simplejson
         return simplejson.loads(content[:-1])
 
-    def get(self, format, tags):
+    def get(self, format, tags, limit=6):
         """get the response for your tags. Three formats supported by now:
         object, that returns a dict, json, that returns a json string
         and XML, that returns XML"""
         handler = getattr(self, '_do_get_%s' % format.lower(),None)
         if handler:
-            return  handler(tags)
+            return  handler(tags,limit)
         else:
             raise NotImplementedError
 
